pub enum ProgressTokenValue {
String(String),
Number(i64),
}Expand description
Core MCP protocol types and error handling Progress token value — can be a string or a number per MCP 2025-11-25. See MCP spec
Variants